@@ -2,10 +2,10 @@
 /*
  * gsf-libxml.c :
  *
- * Copyright (C) 2002 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2002-2003 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2.1 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,7 +13,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
@@ -402,9 +402,12 @@ static xmlSAXHandler gsfXMLInParser = {
  * gsf_xml_in_doc_new :
  * @doc :
  *
- * link  up the static parent descriptors
+ * Put the nodes in the NULL terminated array starting at @root and the name
+ * spaces in the NULL terminated array starting at @ns together.  Link them up
+ * and prepare the static data structures necessary to validate a doument based
+ * on that description.
  *
- * Returns : TRUE on success
+ * Returns : NULL on error
  **/
 GsfXMLInDoc *
 gsf_xml_in_doc_new (GsfXMLInNode *root, GsfXMLInNS *ns)
@@ -433,7 +436,7 @@ gsf_xml_in_doc_new (GsfXMLInNode *root, GsfXMLInNS *ns)
 
 	symbols = g_hash_table_new (g_str_hash, g_str_equal);
 	for (node = root; node->id != NULL ; node++ ) {
-		g_return_val_if_fail (!node->parent_initialized, FALSE);
+		g_return_val_if_fail (!node->parent_initialized, NULL);
 
 		tmp = g_hash_table_lookup (symbols, node->id);
 		if (tmp != NULL) {
@@ -441,7 +444,7 @@ gsf_xml_in_doc_new (GsfXMLInNode *root, GsfXMLInNS *ns)
 			if (node->start != NULL || node->end != NULL ||
 			    node->has_content != FALSE || node->user_data.v_int != 0) {
 				g_warning ("ID '%s' has already been registered", node->id);
-				return FALSE;
+				return NULL;
 			}
 			real_node = tmp;
 		} else {
@@ -454,7 +457,7 @@ gsf_xml_in_doc_new (GsfXMLInNode *root, GsfXMLInNS *ns)
 		tmp = g_hash_table_lookup (symbols, node->parent_id);
 		if (tmp != NULL) {
 			GSList *ptr;
-			GsfXMLInNodeGroup *group;
+			GsfXMLInNodeGroup *group = NULL;
 			GsfXMLInNS const *ns = NULL;
 			
 			ns = (real_node->ns_id < 0) ? NULL
@@ -473,7 +476,7 @@ gsf_xml_in_doc_new (GsfXMLInNode *root, GsfXMLInNS *ns)
 			group->elem = g_slist_prepend (group->elem, real_node);
 		} else if (strcmp (node->id, node->parent_id)) {
 			g_warning ("Parent ID '%s' unknown", node->parent_id);
-			return FALSE;
+			return NULL;
 		}
 		node->parent_initialized = TRUE;
 	}
