@@ -2,12 +2,12 @@
 /*
  * gsf-msole-utils.c: 
  *
- * Copyright (C) 2002 Jody Goldberg (jody@gnome.org)
- * Copyright (C) 2002 Dom Lachowicz (cinamod@hotmail.com)
+ * Copyright (C) 2002-2003 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2002-2003 Dom Lachowicz (cinamod@hotmail.com)
  * excel_iconv* family of functions (C) 2001 by Vlad Harchev <hvv@hippo.ru>
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2.1 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -15,7 +15,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
@@ -226,6 +226,7 @@ msole_prop_parse (GsfMSOleMetaDataSection *section,
 	GValue *res;
 	char *str;
 	guint32 len;
+	gsize gslen;
 	gboolean const is_vector = type & VT_VECTOR;
 
 	g_return_val_if_fail (!(type & (unsigned)(~0x1fff)), NULL); /* not valid in a prop set */
@@ -360,9 +361,11 @@ msole_prop_parse (GsfMSOleMetaDataSection *section,
 
 		g_return_val_if_fail (*data + 4 + len <= data_end, NULL);
 
+		gslen = 0;
 		str = g_convert_with_iconv (*data + 4,
 			len * section->char_size,
-			section->iconv_handle, &len, NULL, NULL);
+			section->iconv_handle, &gslen, NULL, NULL);
+		len = (guint32)gslen;
 
 		g_value_init (res, G_TYPE_STRING);
 		g_value_set_string (res, str);
@@ -379,7 +382,8 @@ msole_prop_parse (GsfMSOleMetaDataSection *section,
 		g_return_val_if_fail (*data + 4 + len <= data_end, NULL);
 
 		str = g_convert (*data + 4, len*2,
-				 "UTF-8", "UTF-16LE", &len, NULL, NULL);
+				 "UTF-8", "UTF-16LE", &gslen, NULL, NULL);
+		len = (guint32)gslen;
 
 		g_value_init (res, G_TYPE_STRING);
 		g_value_set_string (res, str);
@@ -483,6 +487,7 @@ msole_prop_read (GsfInput *in,
 	/* dictionary is magic */
 	if (props[i].id == 0) {
 		guint32 len, id, i, n;
+		gsize gslen;
 		char *name;
 		guint8 const *start = data;
 
@@ -500,9 +505,11 @@ msole_prop_read (GsfInput *in,
 
 			g_return_val_if_fail (len < 0x10000, NULL);
 
+			gslen = 0;
 			name = g_convert_with_iconv (data + 8,
 				len * section->char_size,
-				section->iconv_handle, &len, NULL, NULL);
+				section->iconv_handle, &gslen, NULL, NULL);
+			len = (guint32)gslen;
 			data += 8 + len;
 
 			d (printf ("\t%u == %s\n", id, name););
@@ -573,7 +580,7 @@ gsf_msole_metadata_read (GsfInput *in, GError **err)
 	}
 
 	/* extract the section info */
-	sections = g_alloca (sizeof (GsfMSOleMetaDataSection)* num_sections);
+	sections = (GsfMSOleMetaDataSection *)g_alloca (sizeof (GsfMSOleMetaDataSection)* num_sections);
 	for (i = 0 ; i < num_sections ; i++) {
 		data = gsf_input_read (in, 20, NULL);
 		if (NULL == data) {
@@ -1259,7 +1266,6 @@ GIConv
 gsf_msole_iconv_open_codepage_for_import (char const *to, guint codepage)
 {
 	GIConv iconv_handle;
-
 	g_return_val_if_fail (to != NULL, (GIConv)(-1));
 
 	if (codepage != 1200 && codepage != 1201) {
@@ -1268,16 +1274,28 @@ gsf_msole_iconv_open_codepage_for_import (char const *to, guint codepage)
 		g_free (src_charset);
 		if (iconv_handle != (GIConv)(-1))
 			return iconv_handle;
-		g_warning ("Unknown codepage %d", codepage);
-		return (GIConv)(-1);
+	} else {
+		const char *from = (codepage == 1200) ? "UTF-16LE" : "UTF-16BE";
+		iconv_handle = g_iconv_open (to, from);
+		if (iconv_handle != (GIConv)(-1))
+			return iconv_handle;
 	}
 
-	iconv_handle = g_iconv_open (to,
-		(codepage == 1200) ? "UTF-16LE" : "UTF-16BE");
-	if (iconv_handle != (GIConv)(-1))
-		return iconv_handle;
-	g_warning ("Unable to open an iconv handle from %s -> %s",
-		   (codepage == 1200) ? "UTF-16LE" : "UTF-16BE", to);
+	/* Try aliases.  */
+	if (codepage == 10000) {
+		/* gnu iconv.  */
+		iconv_handle = g_iconv_open (to, "MACROMAN");
+		if (iconv_handle != (GIConv)(-1))
+			return iconv_handle;
+
+		/* glibc.  */
+		iconv_handle = g_iconv_open (to, "MACINTOSH");
+		if (iconv_handle != (GIConv)(-1))
+			return iconv_handle;
+	}
+
+	g_warning ("Unable to open an iconv handle from codepage %d -> %s",
+		   codepage, to);
 	return (GIConv)(-1);
 }
 
