@@ -2,10 +2,10 @@
 /*
  * gsf-outfile-msole.c: 
  *
- * Copyright (C) 2002 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2002-2003 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2.1 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,7 +13,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Outc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
@@ -295,16 +295,20 @@ gsf_outfile_msole_close (GsfOutput *output)
 
 			memset (buf, 0, DIRENT_SIZE);
 
-			/* be wary about endianness */
-			if (gsf_output_name (GSF_OUTPUT (child)) != NULL) {
+			if (i > 0 && /* no name for the root */
+			    gsf_output_name (GSF_OUTPUT (child)) != NULL) {
+			    /* be wary about endianness */
 				gunichar2 *name_utf16 = g_utf8_to_utf16 (
 					gsf_output_name (GSF_OUTPUT (child)),
 					-1, NULL, &name_len, NULL);
+				if (name_len >= DIRENT_MAX_NAME_SIZE)
+					name_len = DIRENT_MAX_NAME_SIZE-1;
 				for (j = 0 ; j < name_len ; j++)
 					GSF_LE_SET_GUINT16 (buf + j*2, name_utf16 [j]);
 				g_free (name_utf16);
+				name_len++;
 			}
-			GSF_LE_SET_GUINT16 (buf + DIRENT_NAME_LEN, name_len*2 + 2);
+			GSF_LE_SET_GUINT16 (buf + DIRENT_NAME_LEN, name_len*2);
 
 			if (child->root == child) {
 				GSF_LE_SET_GUINT8  (buf + DIRENT_TYPE,	DIRENT_TYPE_ROOTDIR);
@@ -589,7 +593,7 @@ gsf_outfile_msole_new_child (GsfOutfile *parent, char const *name,
 	} else {
 		/* start as small block */
 		child->type = MSOLE_SMALL_BLOCK;
-		child->content.small_block.buf = g_malloc0 (OLE_DEFAULT_THRESHOLD);
+		child->content.small_block.buf = g_new0 (guint8, OLE_DEFAULT_THRESHOLD);
 	}
 	g_object_ref (G_OBJECT (ole_parent->sink));
 	child->sink   = ole_parent->sink;
@@ -647,7 +651,7 @@ GSF_CLASS (GsfOutfileMSOle, gsf_outfile_msole,
  *
  * Returns : the new ole file handler
  **/
-GsfOutfile *
+GsfOutfileMSOle *
 gsf_outfile_msole_new (GsfOutput *sink)
 {
 	static guint8 const default_header [] = {
@@ -705,5 +709,5 @@ gsf_outfile_msole_new (GsfOutput *sink)
 
 	gsf_output_write (sink, sizeof (default_header), default_header);
 
-	return GSF_OUTFILE (ole);
+	return ole;
 }
